==> snortsms-0.14.9.tbz: www/snortsms/sensorconf/dsp_tab_snort.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$jump = $Fusebox['circuit'] . "." . $Fusebox['fuseaction'];

$source[0]['name'] = "Variables";
$source[0]['fuse'] = "variables";
$source[0]['type'] = "V";
$source[0]['table'] = "TBL_VARIABLES";
$source[0]['selected'] = 0;
$source[0]['total'] = 0;
$source[1]['name'] = "Preprocessors";
$source[1]['fuse'] = "preprocessors";
$source[1]['type'] = "P";
$source[1]['table'] = "TBL_PREPROCESSORS";
$source[1]['selected'] = 0;
$source[1]['total'] = 0;
$source[2]['name'] = "Output Plugins";
$source[2]['fuse'] = "outputs";
$source[2]['type'] = "O";
$source[2]['table'] = "TBL_OUTPUTS";
$source[2]['selected'] = 0;
$source[2]['total'] = 0;
$source[3]['name'] = "References";
$source[3]['fuse'] = "references";
$source[3]['type'] = "R";
$source[3]['table'] = "TBL_REFERENCES";
$source[3]['selected'] = 0;
$source[3]['total'] = 0;
$source[4]['name'] = "Classifications";
$source[4]['fuse'] = "classifications";
$source[4]['type'] = "C";
$source[4]['table'] = "TBL_CLASSIFICATIONS";
$source[4]['selected'] = 0;
$source[4]['total'] = 0;
$source[5]['name'] = "Rule Types";
$source[5]['fuse'] = "ruletypes";
$source[5]['type'] = "X";
$source[5]['table'] = "TBL_RULE_TYPES";
$source[5]['selected'] = 0;
$source[5]['total'] = 0;
$source[6]['name'] = "Rule Profiles";
$source[6]['fuse'] = "policies";
$source[6]['type'] = "T";
$source[6]['table'] = "TBL_POLICIES";
$source[6]['selected'] = 0;
$source[6]['total'] = 0;

for($i=0; $i < count($source); $i++)
	{	
	/*** Get statistics ***/
	$sql = "SELECT id FROM TBL_ASSIGNMENTS WHERE type = '".$source[$i]['type']."' AND sensorid = " . $temp_sensorid;
	$rsStat = $db->query($sql); if (DB::isError($rsStat)) { die ($rsStat->getdebugInfo());}
	$source[$i]['selected'] = $rsStat->numRows();
	$sql = "SELECT id FROM " . $source[$i]['table'];	
	$rsStat = $db->query($sql); if (DB::isError($rsStat)) { die ($rsStat->getdebugInfo());}
	$source[$i]['total'] = $rsStat->numRows();
	//print "<P>  ".$source[$i]['selected']."   ".$source[$i]['total']." </p>\n";
	}



	

$urlparams = "&tab=".$tab."&FRM_sensorid=".$temp_sensorid."&jump=".$jump;
?>
<FORM action="index.php?fuseaction=sensorconf.save" method="POST">
<INPUT type="hidden" name="FRM_sensorid" value="<?=$temp_sensorid?>">
<INPUT type="hidden" name="tab" value="<?=$tab?>">
<div align="center">


<table border="0" class="bg2" width="100%">
<tr><td colspan="4">&nbsp;</td></tr>


<tr>
<td class="label" align="right">Snort Daemon Profile:</td>
<td><?=$temp_snortctrl?>&nbsp;<a href="index.php?fuseaction=snortctrl.main">[Add/Edit]</a></td>
<td class="label" align="right">Push sig-msg map:</td><td><?=$temp_sigmsg?></td>
</tr>

<tr><td colspan="4">&nbsp;</td></tr>
<tr><td colspan="4">&nbsp;</td></tr>

<tr><td colspan="4">
<table border="0" class="bg2" cellspacing="0" cellpadding="4" width="100%">
<tr class="label">
<td align="center">Sub Catagory</td>
<td align="center">Selected</td>
<td>&nbsp;</td>
<td align="center">Available</td>
</tr>
<?
foreach ($source as $item)
	{
	?>
	<tr>
	<td align="right"><b><?=$item['name']?></b>&nbsp;</td>
	<td align="center"><span class="box"><?=$item['selected']?></span> <a href="index.php?fuseaction=<?=$item['fuse']?>.select&FRM_sensorid=<?=$temp_sensorid?>" title="Select <?=$item['name']?>">[pick]</a></td>
	<td>&nbsp;</td>
	<td align="center" align="center"><?=$item['total']?></td>
	</tr>
	<?
	}
?>
<tr>
<td colspan="4">&nbsp;</td>
</tr><tr>
<td colspan="4" align="left">Snort Config File: <a href="index.php?fuseaction=sensorconf.gensnortconf&FRM_sensorid=<?=$temp_sensorid?>">[ Preview ]</a>&nbsp;</td>
</tr>
</table>
</td></tr>


<tr><td colspan="4" align="right">
<INPUT type="submit" name="button" value="<?=$temp_button?>">
</td></tr>

</table>
</FORM>

==> snortsms-1.0.0.tbz: www/snortsms/sensorconf/dsp_tab_snort.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$jump = $Fusebox['circuit'] . "." . $Fusebox['fuseaction'];

$source[0]['name'] = "Variables";
$source[0]['fuse'] = "variables";
$source[0]['type'] = "V";
$source[0]['table'] = "TBL_VARIABLES";
$source[0]['selected'] = 0;
$source[0]['total'] = 0;
$source[1]['name'] = "Preprocessors";
$source[1]['fuse'] = "preprocessors";
$source[1]['type'] = "P";
$source[1]['table'] = "TBL_PREPROCESSORS";
$source[1]['selected'] = 0;
$source[1]['total'] = 0;
$source[2]['name'] = "Output Plugins";
$source[2]['fuse'] = "outputs";
$source[2]['type'] = "O";
$source[2]['table'] = "TBL_OUTPUTS";
$source[2]['selected'] = 0;
$source[2]['total'] = 0;
$source[3]['name'] = "Config Directives";
$source[3]['fuse'] = "configs";
$source[3]['type'] = "F";
$source[3]['table'] = "TBL_CONFIGS";
$source[3]['selected'] = 0;
$source[3]['total'] = 0;
$source[4]['name'] = "References";
$source[4]['fuse'] = "references";
$source[4]['type'] = "R";
$source[4]['table'] = "TBL_REFERENCES";
$source[4]['selected'] = 0;
$source[4]['total'] = 0;
$source[5]['name'] = "Classifications";
$source[5]['fuse'] = "classifications";
$source[5]['type'] = "C";
$source[5]['table'] = "TBL_CLASSIFICATIONS";
$source[5]['selected'] = 0;
$source[5]['total'] = 0;
$source[6]['name'] = "Rule Types";
$source[6]['fuse'] = "ruletypes";
$source[6]['type'] = "X";
$source[6]['table'] = "TBL_RULE_TYPES";
$source[6]['selected'] = 0;
$source[6]['total'] = 0;
$source[7]['name'] = "Rule Profiles";
$source[7]['fuse'] = "policies";
$source[7]['type'] = "T";
$source[7]['table'] = "TBL_POLICIES";
$source[7]['selected'] = 0;
$source[7]['total'] = 0;

for($i=0; $i < count($source); $i++)
	{	
	/*** Get statistics ***/
	$sql = "SELECT id FROM TBL_ASSIGNMENTS WHERE type = '".$source[$i]['type']."' AND sensorid = " . $temp_sensorid;
	$rsStat = $db->query($sql); if (DB::isError($rsStat)) { die ($rsStat->getdebugInfo());}
	$source[$i]['selected'] = $rsStat->numRows();
	$sql = "SELECT id FROM " . $source[$i]['table'];	
	$rsStat = $db->query($sql); if (DB::isError($rsStat)) { die ($rsStat->getdebugInfo());}
	$source[$i]['total'] = $rsStat->numRows();
	//print "<P>  ".$source[$i]['selected']."   ".$source[$i]['total']." </p>\n";
	}



	

$urlparams = "&tab=".$tab."&FRM_sensorid=".$temp_sensorid."&jump=".$jump;
?>
<FORM action="index.php?fuseaction=sensorconf.save" method="POST">
<INPUT type="hidden" name="FRM_sensorid" value="<?=$temp_sensorid?>">
<INPUT type="hidden" name="tab" value="<?=$tab?>">
<div align="center">


<table border="0" class="bg2" width="100%">
<tr><td colspan="4">&nbsp;</td></tr>


<tr>
<td class="label" align="right">Snort Daemon Profile:</td>
<td><?=$temp_snortctrl?>&nbsp;<a href="index.php?fuseaction=snortctrl.main">[Add/Edit]</a></td>
<td class="label" align="right">Push sig-msg map:</td><td><?=$temp_sigmsg?></td>
</tr>

<tr><td colspan="4">&nbsp;</td></tr>
<tr><td colspan="4">&nbsp;</td></tr>

<tr><td colspan="4">
<table border="0" class="bg2" cellspacing="0" cellpadding="4" width="100%">
<tr class="label">
<td align="center">Sub Catagory</td>
<td align="center">Selected</td>
<td>&nbsp;</td>
<td align="center">Available</td>
</tr>
<?
foreach ($source as $item)
	{
	?>
	<tr>
	<td align="right"><b><?=$item['name']?></b>&nbsp;</td>
	<td align="center"><span class="box"><?=$item['selected']?></span> <a href="index.php?fuseaction=<?=$item['fuse']?>.select&FRM_sensorid=<?=$temp_sensorid?>" title="Select <?=$item['name']?>">[pick]</a></td>
	<td>&nbsp;</td>
	<td align="center" align="center"><?=$item['total']?></td>
	</tr>
	<?
	}
?>
<tr>
<td colspan="4">&nbsp;</td>
</tr><tr>
<td colspan="4" align="left">Snort Config File: <a href="index.php?fuseaction=sensorconf.gensnortconf&FRM_sensorid=<?=$temp_sensorid?>">[ Preview ]</a>&nbsp;</td>
</tr>
</table>
</td></tr>


<tr><td colspan="4" align="right">
<INPUT type="submit" name="button" value="<?=$temp_button?>">
</td></tr>

</table>
</FORM>
